@@ -11,7 +11,7 @@ import logging
 import sys
 import threading
 
-from adb_shell.adb_device import AdbDeviceTcp
+from adb_shell.adb_device import AdbDeviceTcp, AdbDeviceUsb
 from adb_shell.auth.sign_pythonrsa import PythonRSASigner
 from ppadb.client import Client
 
@@ -21,7 +21,7 @@ from ..exceptions import LockNotAcquiredException
 _LOGGER = logging.getLogger(__name__)
 
 #: Use a timeout for the ADB threading lock if it is supported
-LOCK_KWARGS = {'timeout': DEFAULT_LOCK_TIMEOUT_S} if sys.version_info[0] > 2 and sys.version_info[1] > 1 else {}
+LOCK_KWARGS = {"timeout": DEFAULT_LOCK_TIMEOUT_S} if sys.version_info[0] > 2 and sys.version_info[1] > 1 else {}
 
 if sys.version_info[0] == 2:  # pragma: no cover
     FileNotFoundError = IOError  # pylint: disable=redefined-builtin
@@ -73,11 +73,17 @@ class ADBPythonSync(object):
         The signer for the ADB keys, as loaded by :meth:`ADBPythonSync.load_adbkey`
 
     """
-    def __init__(self, host, port, adbkey='', signer=None):
+
+    def __init__(self, host, port, adbkey="", signer=None):
         self.host = host
         self.port = int(port)
         self.adbkey = adbkey
-        self._adb = AdbDeviceTcp(host=self.host, port=self.port, default_transport_timeout_s=DEFAULT_ADB_TIMEOUT_S)
+
+        if host:
+            self._adb = AdbDeviceTcp(host=self.host, port=self.port, default_transport_timeout_s=DEFAULT_ADB_TIMEOUT_S)
+        else:
+            self._adb = AdbDeviceUsb(default_transport_timeout_s=DEFAULT_ADB_TIMEOUT_S)
+
         self._signer = signer
 
         # keep track of whether the ADB connection is intact
@@ -99,9 +105,7 @@ class ADBPythonSync(object):
         return self._adb.available
 
     def close(self):
-        """Close the ADB socket connection.
-
-        """
+        """Close the ADB socket connection."""
         self._adb.close()
 
     def connect(self, always_log_errors=True, auth_timeout_s=DEFAULT_AUTH_TIMEOUT_S):
@@ -129,11 +133,13 @@ class ADBPythonSync(object):
                         if not self._signer:
                             self._signer = self.load_adbkey(self.adbkey)
 
-                        self._adb.connect(rsa_keys=[self._signer], auth_timeout_s=auth_timeout_s)
+                        self._adb.connect(
+                            rsa_keys=[self._signer], transport_timeout_s=1.0, auth_timeout_s=auth_timeout_s
+                        )
 
                     # Connect without authentication
                     else:
-                        self._adb.connect(auth_timeout_s=auth_timeout_s)
+                        self._adb.connect(transport_timeout_s=1.0, auth_timeout_s=auth_timeout_s)
 
                     # ADB connection successfully established
                     _LOGGER.debug("ADB connection to %s:%d successfully established", self.host, self.port)
@@ -144,7 +150,13 @@ class ADBPythonSync(object):
                     if self._available or always_log_errors:
                         if exc.strerror is None:
                             exc.strerror = "Timed out trying to connect to ADB device."
-                        _LOGGER.warning("Couldn't connect to %s:%d.  %s: %s", self.host, self.port, exc.__class__.__name__, exc.strerror)
+                        _LOGGER.warning(
+                            "Couldn't connect to %s:%d.  %s: %s",
+                            self.host,
+                            self.port,
+                            exc.__class__.__name__,
+                            exc.strerror,
+                        )
 
                     # ADB connection attempt failed
                     self.close()
@@ -153,7 +165,9 @@ class ADBPythonSync(object):
 
                 except Exception as exc:  # pylint: disable=broad-except
                     if self._available or always_log_errors:
-                        _LOGGER.warning("Couldn't connect to %s:%d.  %s: %s", self.host, self.port, exc.__class__.__name__, exc)
+                        _LOGGER.warning(
+                            "Couldn't connect to %s:%d.  %s: %s", self.host, self.port, exc.__class__.__name__, exc
+                        )
 
                     # ADB connection attempt failed
                     self.close()
@@ -187,10 +201,10 @@ class ADBPythonSync(object):
 
         # public key
         try:
-            with open(adbkey + '.pub') as f:
+            with open(adbkey + ".pub") as f:
                 pub = f.read()
         except FileNotFoundError:
-            pub = ''
+            pub = ""
 
         return PythonRSASigner(pub, priv)
 
@@ -206,11 +220,19 @@ class ADBPythonSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB command not sent to %s:%d because adb-shell connection is not established: pull(%s, %s)", self.host, self.port, local_path, device_path)
+            _LOGGER.debug(
+                "ADB command not sent to %s:%d because adb-shell connection is not established: pull(%s, %s)",
+                self.host,
+                self.port,
+                local_path,
+                device_path,
+            )
             return
 
         with _acquire(self._adb_lock):
-            _LOGGER.debug("Sending command to %s:%d via adb-shell: pull(%s, %s)", self.host, self.port, local_path, device_path)
+            _LOGGER.debug(
+                "Sending command to %s:%d via adb-shell: pull(%s, %s)", self.host, self.port, local_path, device_path
+            )
             self._adb.pull(device_path, local_path)
             return
 
@@ -226,11 +248,19 @@ class ADBPythonSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB command not sent to %s:%d because adb-shell connection is not established: push(%s, %s)", self.host, self.port, local_path, device_path)
+            _LOGGER.debug(
+                "ADB command not sent to %s:%d because adb-shell connection is not established: push(%s, %s)",
+                self.host,
+                self.port,
+                local_path,
+                device_path,
+            )
             return
 
         with _acquire(self._adb_lock):
-            _LOGGER.debug("Sending command to %s:%d via adb-shell: push(%s, %s)", self.host, self.port, local_path, device_path)
+            _LOGGER.debug(
+                "Sending command to %s:%d via adb-shell: push(%s, %s)", self.host, self.port, local_path, device_path
+            )
             self._adb.push(local_path, device_path)
             return
 
@@ -244,7 +274,11 @@ class ADBPythonSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB screencap not taken from %s:%d because adb-shell connection is not established", self.host, self.port)
+            _LOGGER.debug(
+                "ADB screencap not taken from %s:%d because adb-shell connection is not established",
+                self.host,
+                self.port,
+            )
             return None
 
         with _acquire(self._adb_lock):
@@ -269,7 +303,12 @@ class ADBPythonSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB command not sent to %s:%d because adb-shell connection is not established: %s", self.host, self.port, cmd)
+            _LOGGER.debug(
+                "ADB command not sent to %s:%d because adb-shell connection is not established: %s",
+                self.host,
+                self.port,
+                cmd,
+            )
             return None
 
         with _acquire(self._adb_lock):
@@ -292,7 +331,8 @@ class ADBServerSync(object):
         The port for the ADB server
 
     """
-    def __init__(self, host, port=5555, adb_server_ip='', adb_server_port=5037):
+
+    def __init__(self, host, port=5555, adb_server_ip="", adb_server_port=5037):
         self.host = host
         self.port = int(port)
         self.adb_server_ip = adb_server_ip
@@ -349,18 +389,30 @@ class ADBServerSync(object):
                 # Catch exceptions
                 try:
                     self._adb_client = Client(host=self.adb_server_ip, port=self.adb_server_port)
-                    self._adb_device = self._adb_client.device('{}:{}'.format(self.host, self.port))
+                    self._adb_device = self._adb_client.device("{}:{}".format(self.host, self.port))
 
                     # ADB connection successfully established
                     if self._adb_device:
-                        _LOGGER.debug("ADB connection to %s:%d via ADB server %s:%d successfully established", self.host, self.port, self.adb_server_ip, self.adb_server_port)
+                        _LOGGER.debug(
+                            "ADB connection to %s:%d via ADB server %s:%d successfully established",
+                            self.host,
+                            self.port,
+                            self.adb_server_ip,
+                            self.adb_server_port,
+                        )
                         self._available = True
                         self._was_available = True
                         return True
 
                     # ADB connection attempt failed (without an exception)
                     if self._was_available or always_log_errors:
-                        _LOGGER.warning("Couldn't connect to %s:%d via ADB server %s:%d because the server is not connected to the device", self.host, self.port, self.adb_server_ip, self.adb_server_port)
+                        _LOGGER.warning(
+                            "Couldn't connect to %s:%d via ADB server %s:%d because the server is not connected to the device",
+                            self.host,
+                            self.port,
+                            self.adb_server_ip,
+                            self.adb_server_port,
+                        )
 
                     self.close()
                     self._available = False
@@ -370,7 +422,14 @@ class ADBServerSync(object):
                 # ADB connection attempt failed
                 except Exception as exc:  # noqa pylint: disable=broad-except
                     if self._was_available or always_log_errors:
-                        _LOGGER.warning("Couldn't connect to %s:%d via ADB server %s:%d, error: %s", self.host, self.port, self.adb_server_ip, self.adb_server_port, exc)
+                        _LOGGER.warning(
+                            "Couldn't connect to %s:%d via ADB server %s:%d, error: %s",
+                            self.host,
+                            self.port,
+                            self.adb_server_ip,
+                            self.adb_server_port,
+                            exc,
+                        )
 
                     self.close()
                     self._available = False
@@ -378,7 +437,13 @@ class ADBServerSync(object):
                     return False
 
         except LockNotAcquiredException:
-            _LOGGER.warning("Couldn't connect to %s:%d via ADB server %s:%d because pure-python-adb lock not acquired.", self.host, self.port, self.adb_server_ip, self.adb_server_port)
+            _LOGGER.warning(
+                "Couldn't connect to %s:%d via ADB server %s:%d because pure-python-adb lock not acquired.",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+            )
             self.close()
             self._available = False
             self._was_available = False
@@ -396,11 +461,27 @@ class ADBServerSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB command not sent to %s:%d via ADB server %s:%d because pure-python-adb connection is not established: pull(%s, %s)", self.host, self.port, self.adb_server_ip, self.adb_server_port, local_path, device_path)
+            _LOGGER.debug(
+                "ADB command not sent to %s:%d via ADB server %s:%d because pure-python-adb connection is not established: pull(%s, %s)",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+                local_path,
+                device_path,
+            )
             return
 
         with _acquire(self._adb_lock):
-            _LOGGER.debug("Sending command to %s:%d via ADB server %s:%d: pull(%s, %s)", self.host, self.port, self.adb_server_ip, self.adb_server_port, local_path, device_path)
+            _LOGGER.debug(
+                "Sending command to %s:%d via ADB server %s:%d: pull(%s, %s)",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+                local_path,
+                device_path,
+            )
             self._adb_device.pull(device_path, local_path)
             return
 
@@ -416,11 +497,27 @@ class ADBServerSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB command not sent to %s:%d via ADB server %s:%d because pure-python-adb connection is not established: push(%s, %s)", self.host, self.port, self.adb_server_ip, self.adb_server_port, local_path, device_path)
+            _LOGGER.debug(
+                "ADB command not sent to %s:%d via ADB server %s:%d because pure-python-adb connection is not established: push(%s, %s)",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+                local_path,
+                device_path,
+            )
             return
 
         with _acquire(self._adb_lock):
-            _LOGGER.debug("Sending command to %s:%d via ADB server %s:%d: push(%s, %s)", self.host, self.port, self.adb_server_ip, self.adb_server_port, local_path, device_path)
+            _LOGGER.debug(
+                "Sending command to %s:%d via ADB server %s:%d: push(%s, %s)",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+                local_path,
+                device_path,
+            )
             self._adb_device.push(local_path, device_path)
             return
 
@@ -434,11 +531,23 @@ class ADBServerSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB screencap not taken from %s:%d via ADB server %s:%d because pure-python-adb connection is not established", self.host, self.port, self.adb_server_ip, self.adb_server_port)
+            _LOGGER.debug(
+                "ADB screencap not taken from %s:%d via ADB server %s:%d because pure-python-adb connection is not established",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+            )
             return None
 
         with _acquire(self._adb_lock):
-            _LOGGER.debug("Taking screencap from %s:%d via ADB server %s:%d", self.host, self.port, self.adb_server_ip, self.adb_server_port)
+            _LOGGER.debug(
+                "Taking screencap from %s:%d via ADB server %s:%d",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+            )
             return self._adb_device.screencap()
 
     def shell(self, cmd):
@@ -456,9 +565,23 @@ class ADBServerSync(object):
 
         """
         if not self.available:
-            _LOGGER.debug("ADB command not sent to %s:%d via ADB server %s:%d because pure-python-adb connection is not established: %s", self.host, self.port, self.adb_server_ip, self.adb_server_port, cmd)
+            _LOGGER.debug(
+                "ADB command not sent to %s:%d via ADB server %s:%d because pure-python-adb connection is not established: %s",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+                cmd,
+            )
             return None
 
         with _acquire(self._adb_lock):
-            _LOGGER.debug("Sending command to %s:%d via ADB server %s:%d: %s", self.host, self.port, self.adb_server_ip, self.adb_server_port, cmd)
+            _LOGGER.debug(
+                "Sending command to %s:%d via ADB server %s:%d: %s",
+                self.host,
+                self.port,
+                self.adb_server_ip,
+                self.adb_server_port,
+                cmd,
+            )
             return self._adb_device.shell(cmd)
