@@ -67,7 +67,16 @@ class BaseTVAsync(BaseTV):
 
     """
 
-    def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None, signer=None):
+    def __init__(
+        self,
+        host,
+        port=5555,
+        adbkey="",
+        adb_server_ip="",
+        adb_server_port=5037,
+        state_detection_rules=None,
+        signer=None,
+    ):
         # the handler for ADB commands
         if not adb_server_ip:
             # python-adb
@@ -191,14 +200,15 @@ class BaseTVAsync(BaseTV):
             A dictionary with keys ``'wifimac'``, ``'ethmac'``, ``'serialno'``, ``'manufacturer'``, ``'model'``, and ``'sw_version'``
 
         """
-        properties = await self._adb.shell(constants.CMD_MANUFACTURER + " && " +
-                                           constants.CMD_MODEL + " && " +
-                                           constants.CMD_SERIALNO + " && " +
-                                           constants.CMD_VERSION + " && " +
-                                           constants.CMD_MAC_WLAN0 + " && " +
-                                           constants.CMD_MAC_ETH0)
+        properties = await self._adb.shell(constants.CMD_DEVICE_PROPERTIES)
 
         self._parse_device_properties(properties)
+
+        ethmac_response = await self._adb.shell(constants.CMD_MAC_ETH0)
+        wifimac_response = await self._adb.shell(constants.CMD_MAC_WLAN0)
+        self.device_properties["ethmac"] = self._parse_mac_address(ethmac_response)
+        self.device_properties["wifimac"] = self._parse_mac_address(wifimac_response)
+
         return self.device_properties
 
     # ======================================================================= #
@@ -240,7 +250,7 @@ class BaseTVAsync(BaseTV):
             Whether or not the device is awake (screensaver is not running)
 
         """
-        return await self._adb.shell(constants.CMD_AWAKE + constants.CMD_SUCCESS1_FAILURE0) == '1'
+        return await self._adb.shell(constants.CMD_AWAKE + constants.CMD_SUCCESS1_FAILURE0) == "1"
 
     async def current_app(self):
         """Return the current app.
@@ -251,10 +261,25 @@ class BaseTVAsync(BaseTV):
             The ID of the current app, or ``None`` if it could not be determined
 
         """
-        current_app_response = await self._adb.shell(self._cmd_current_app)
+        current_app_response = await self._adb.shell(self._cmd_current_app())
 
         return self._current_app(current_app_response)
 
+    async def current_app_media_session_state(self):
+        """Get the current app and the state from the output of ``dumpsys media_session``.
+
+        Returns
+        -------
+        str, None
+            The current app, or ``None`` if it could not be determined
+        int, None
+            The state from the output of the ADB shell command ``dumpsys media_session``, or ``None`` if it could not be determined
+
+        """
+        media_session_state_response = await self._adb.shell(self._cmd_current_app_media_session_state())
+
+        return self._current_app_media_session_state(media_session_state_response)
+
     async def get_hdmi_input(self):
         """Get the HDMI input from the output of :py:const:`androidtv.constants.CMD_HDMI_INPUT`.
 
@@ -301,12 +326,23 @@ class BaseTVAsync(BaseTV):
             The state from the output of the ADB shell command ``dumpsys media_session``, or ``None`` if it could not be determined
 
         """
-        media_session_state_response = await self._adb.shell(constants.CMD_MEDIA_SESSION_STATE_FULL)
-
-        _, media_session_state = self._current_app_media_session_state(media_session_state_response)
+        _, media_session_state = await self.current_app_media_session_state()
 
         return media_session_state
 
+    async def running_apps(self):
+        """Return a list of running user applications.
+
+        Returns
+        -------
+        list
+            A list of the running apps
+
+        """
+        running_apps_response = await self._adb.shell(self._cmd_running_apps())
+
+        return self._running_apps(running_apps_response)
+
     async def screen_on(self):
         """Check if the screen is on.
 
@@ -316,7 +352,47 @@ class BaseTVAsync(BaseTV):
             Whether or not the device is on
 
         """
-        return await self._adb.shell(constants.CMD_SCREEN_ON + constants.CMD_SUCCESS1_FAILURE0) == '1'
+        return await self._adb.shell(constants.CMD_SCREEN_ON + constants.CMD_SUCCESS1_FAILURE0) == "1"
+
+    async def screen_on_awake_wake_lock_size(self):
+        """Check if the screen is on and the device is awake, and get the wake lock size.
+
+        Returns
+        -------
+        bool
+            Whether or not the device is on
+        bool
+            Whether or not the device is awake (screensaver is not running)
+        int, None
+            The size of the current wake lock, or ``None`` if it could not be determined
+
+        """
+        output = await self._adb.shell(constants.CMD_SCREEN_ON_AWAKE_WAKE_LOCK_SIZE)
+
+        return self._screen_on_awake_wake_lock_size(output)
+
+    async def stream_music_properties(self):
+        """Get various properties from the "STREAM_MUSIC" block from ``dumpsys audio``..
+
+        Returns
+        -------
+        audio_output_device : str, None
+            The current audio playback device, or ``None`` if it could not be determined
+        is_volume_muted : bool, None
+            Whether or not the volume is muted, or ``None`` if it could not be determined
+        volume : int, None
+            The absolute volume level, or ``None`` if it could not be determined
+        volume_level : float, None
+            The volume level (between 0 and 1), or ``None`` if it could not be determined
+
+        """
+        stream_music = await self._get_stream_music()
+        audio_output_device = self._audio_output_device(stream_music)
+        volume = self._volume(stream_music, audio_output_device)
+        volume_level = self._volume_level(volume)
+        is_volume_muted = self._is_volume_muted(stream_music)
+
+        return audio_output_device, is_volume_muted, volume, volume_level
 
     async def volume(self):
         """Get the absolute volume level.
@@ -405,7 +481,7 @@ class BaseTVAsync(BaseTV):
             A dictionary with keys ``'output'`` and ``'retcode'``, if they could be determined; otherwise, an empty dictionary
 
         """
-        cmd = 'monkey -p {} -c {} {}; echo $?'.format(pkg, intent, count)
+        cmd = "monkey -p {} -c {} {}; echo $?".format(pkg, intent, count)
 
         # adb shell outputs in weird format, so we cut it into lines,
         # separate the retcode and return info to the user
@@ -428,7 +504,7 @@ class BaseTVAsync(BaseTV):
             The ID of the app that will be launched
 
         """
-        await self._adb.shell(self._cmd_launch_app.format(app))
+        await self._adb.shell(self._cmd_launch_app(app))
 
     async def stop_app(self, app):
         """Stop an app.
@@ -471,7 +547,7 @@ class BaseTVAsync(BaseTV):
             The Key constant
 
         """
-        await self._adb.shell('input keyevent {0}'.format(key))
+        await self._adb.shell("input keyevent {0}".format(key))
 
     async def power(self):
         """Send power action."""
@@ -546,6 +622,19 @@ class BaseTVAsync(BaseTV):
         """Send media previous action (results in rewind)."""
         await self._key(constants.KEY_PREVIOUS)
 
+    # ======================================================================= #
+    #                                                                         #
+    #                   "key" methods: turn on/off commands                   #
+    #                                                                         #
+    # ======================================================================= #
+    async def turn_on(self):
+        """Turn on the device."""
+        await self._adb.shell(self._cmd_turn_on())
+
+    async def turn_off(self):
+        """Turn off the device."""
+        await self._adb.shell(self._cmd_turn_off())
+
     # ======================================================================= #
     #                                                                         #
     #                   "key" methods: alphanumeric commands                  #
@@ -724,7 +813,7 @@ class BaseTVAsync(BaseTV):
             if not self.max_volume:
                 return None
 
-        new_volume = int(min(max(round(self.max_volume * volume_level), 0.), self.max_volume))
+        new_volume = int(min(max(round(self.max_volume * volume_level), 0.0), self.max_volume))
 
         await self._adb.shell("media volume --show --stream 3 --set {}".format(new_volume))
 
@@ -787,7 +876,7 @@ class BaseTVAsync(BaseTV):
             return None
 
         # return the new volume level
-        return max(current_volume - 1, 0.) / self.max_volume
+        return max(current_volume - 1, 0.0) / self.max_volume
 
     # ======================================================================= #
     #                                                                         #
@@ -813,6 +902,12 @@ class BaseTVAsync(BaseTV):
             The events converted to ``sendevent`` commands
 
         """
-        getevent = await self._adb.shell("( getevent ) & pid=$!; ( sleep {} && kill -HUP $pid ) 2>/dev/null & watcher=$!; if wait $pid 2>/dev/null; then echo 'your command finished'; kill -HUP -P $watcher; wait $watcher; else echo 'your command was interrupted'; fi".format(timeout_s))
+        getevent = await self._adb.shell(
+            "( getevent ) & pid=$!; ( sleep {} && kill -HUP $pid ) 2>/dev/null & watcher=$!; if wait $pid 2>/dev/null; then echo 'your command finished'; kill -HUP -P $watcher; wait $watcher; else echo 'your command was interrupted'; fi".format(
+                timeout_s
+            )
+        )
 
-        return " && ".join([self._parse_getevent_line(line) for line in getevent.splitlines() if line.startswith("/") and ":" in line])
+        return " && ".join(
+            [self._parse_getevent_line(line) for line in getevent.splitlines() if line.startswith("/") and ":" in line]
+        )
